<?php
/**
 * Theme Functions
 *
 * @package Betheme
 * @author Muffin group
 * @link https://muffingroup.com
 */

define('MFN_THEME_VERSION', '21.0.6');

// theme related filters

add_filter('widget_text', 'do_shortcode');

add_filter('the_excerpt', 'shortcode_unautop');
add_filter('the_excerpt', 'do_shortcode');

/**
 * White Label
 * IMPORTANT: We recommend the use of Child Theme to change this
 */

defined('WHITE_LABEL') or define('WHITE_LABEL', false);

/**
 * Loads Theme Textdomain
 */

load_theme_textdomain('betheme', get_template_directory() .'/languages'); // frontend
load_theme_textdomain('mfn-opts', get_template_directory() .'/languages'); // admin panel

/**
 * Loads the Options Panel
 */

if (! function_exists('mfn_admin_scripts')) {
	function mfn_admin_scripts()
	{
		wp_enqueue_script('jquery-ui-sortable');
	}
}
add_action('admin_enqueue_scripts', 'mfn_admin_scripts');

require_once(get_theme_file_path('/muffin-options/theme-options.php'));

/**
 * Loads Theme Functions
 */

$theme_disable = mfn_opts_get('theme-disable');

// functions

require_once(get_theme_file_path('/functions/theme-functions.php'));

// header

require_once(get_theme_file_path('/functions/theme-head.php'));

// menu

require_once(get_theme_file_path('/functions/theme-menu.php'));
if (! isset($theme_disable['mega-menu'])) {
	require_once(get_theme_file_path('/functions/theme-mega-menu.php'));

}

// builder

require_once(get_theme_file_path('/functions/builder/fields.php'));
require_once(get_theme_file_path('/functions/builder/back.php'));
require_once(get_theme_file_path('/functions/builder/front.php'));

// post types

$post_types_disable = mfn_opts_get('post-type-disable');

if (! isset($post_types_disable['client'])) {
	require_once(get_theme_file_path('/functions/meta-client.php'));
}
if (! isset($post_types_disable['offer'])) {
	require_once(get_theme_file_path('/functions/meta-offer.php'));
}
if (! isset($post_types_disable['portfolio'])) {
	require_once(get_theme_file_path('/functions/meta-portfolio.php'));
}
if (! isset($post_types_disable['slide'])) {
	require_once(get_theme_file_path('/functions/meta-slide.php'));
}
if (! isset($post_types_disable['testimonial'])) {
	require_once(get_theme_file_path('/functions/meta-testimonial.php'));
}

if (! isset($post_types_disable['layout'])) {
	require_once(get_theme_file_path('/functions/meta-layout.php'));
}
if (! isset($post_types_disable['template'])) {
	require_once(get_theme_file_path('/functions/meta-template.php'));
}

require_once(get_theme_file_path('/functions/meta-page.php'));
require_once(get_theme_file_path('/functions/meta-post.php'));


// includes

require_once(get_theme_file_path('/includes/content-post.php'));
require_once(get_theme_file_path('/includes/content-portfolio.php'));

// shortcodes

require_once(get_theme_file_path('/functions/theme-shortcodes.php'));

// hooks

require_once(get_theme_file_path('/functions/theme-hooks.php'));

// widgets

require_once(get_theme_file_path('/functions/widget-functions.php'));
require_once(get_theme_file_path('/functions/widget-flickr.php'));
require_once(get_theme_file_path('/functions/widget-login.php'));
require_once(get_theme_file_path('/functions/widget-menu.php'));
require_once(get_theme_file_path('/functions/widget-recent-comments.php'));
require_once(get_theme_file_path('/functions/widget-recent-posts.php'));
require_once(get_theme_file_path('/functions/widget-tag-cloud.php'));

// TinyMCE

require_once(get_theme_file_path('/functions/tinymce/tinymce.php'));

// plugins

require_once(get_theme_file_path('/functions/class-love.php'));
require_once(get_theme_file_path('/functions/plugins/visual-composer.php'));

// WooCommerce specified functions

if (function_exists('is_woocommerce')) {
	require_once(get_theme_file_path('/functions/theme-woocommerce.php'));
}

// disable responsive images in WP 4.4+ if Retina.js enabled

if (mfn_opts_get('retina-js')) {
	add_filter('wp_calculate_image_srcset', '__return_false');
}

// hide activation and update specific parts

if (! mfn_opts_get('plugin-rev')) {
	if (function_exists('set_revslider_as_theme')) {
		set_revslider_as_theme();
	}
}

if (! mfn_opts_get('plugin-layer')) {
	add_action('layerslider_ready', 'mfn_layerslider_overrides');
	function mfn_layerslider_overrides()
	{
		// Disable auto-updates
		$GLOBALS['lsAutoUpdateBox'] = false;
	}
}

if (! mfn_opts_get('plugin-visual')) {
	add_action('vc_before_init', 'mfn_vc_set_as_theme');
	function mfn_vc_set_as_theme()
	{
		vc_set_as_theme();
	}
}

// dashboard

if (is_admin()) {
	require_once(get_theme_file_path('/functions/admin/class-mfn-api.php'));
	require_once(get_theme_file_path('/functions/admin/class-mfn-helper.php'));
	require_once(get_theme_file_path('/functions/admin/class-mfn-update.php'));

	require_once(get_theme_file_path('/functions/admin/class-mfn-dashboard.php'));
	$mfn_dashboard = new Mfn_Dashboard();

	if (! isset($theme_disable['demo-data'])) {
		require_once(get_theme_file_path('/functions/importer/class-mfn-importer.php'));
	}

	require_once(get_theme_file_path('/functions/admin/tgm/class-mfn-tgmpa.php'));

	if (! mfn_is_hosted()) {
		require_once(get_theme_file_path('/functions/admin/class-mfn-status.php'));
	}

	require_once(get_theme_file_path('/functions/admin/class-mfn-support.php'));
	require_once(get_theme_file_path('/functions/admin/class-mfn-changelog.php'));

	require_once(get_theme_file_path('/functions/builder/class-mfn-builder-ajax.php'));
	$mfn_builder_ajax = new Mfn_Builder_Ajax();
}

/**
 * @deprecated 21.0.5
 * Below constants are deprecated and will be removed soon
 * Please check if you use these constants in your Child Theme
 */

define('THEME_DIR', get_template_directory());
define('THEME_URI', get_template_directory_uri());

define('THEME_NAME', 'betheme');
define('THEME_VERSION', MFN_THEME_VERSION);

define('LIBS_DIR', get_template_directory() .'/functions');
define('LIBS_URI', get_template_directory() .'/functions');
